@@ -396,9 +396,9 @@ aisleriot_window_show_about_dialog (AisleriotWindow * window)
                          "program-name",
                          _("AisleRiot"),
                          "version", VERSION,
-                         "title", _("About Aisleriot"),
+                         "title", _("About AisleRiot"),
                          "comments",
-                         _("Aisleriot provides a rule-based solitaire "
+                         _("AisleRiot provides a rule-based solitaire "
                            "card engine that allows many different "
                            "games to be played."),
                          "copyright", "Copyright © 1998-2006 Jonathan Blandford\n"
@@ -410,7 +410,7 @@ aisleriot_window_show_about_dialog (AisleriotWindow * window)
                          "translator-credits", _("translator-credits"),
                          "logo-icon-name", "gnome-aisleriot",
                          "website", "http://wiki.gnome.org/Apps/Aisleriot",
-                         "website-label", _("Aisleriot web site"),
+                         "website-label", _("AisleRiot web site"),
                          "wrap-license", TRUE,
                         NULL);
   g_free (licence);
@@ -489,6 +489,13 @@ help_on_game_cb (GtkAction *action,
   aisleriot_show_help (GTK_WIDGET (window), game_module);
 }
 
+static void
+help_overlay_cb (GSimpleAction *action,
+                 AisleriotWindow *window)
+{
+    g_action_group_activate_action (G_ACTION_GROUP (window), "show-help-overlay", NULL);
+}
+
 static void
 close_window_cb (GtkAction *action,
                  AisleriotWindow *window)
@@ -1848,6 +1855,10 @@ aisleriot_window_init (AisleriotWindow *window)
     { "About", GTK_STOCK_ABOUT, NULL, NULL,
       N_("About this game"),
       G_CALLBACK (help_about_cb) },
+    { "KeyboardShortcuts", NULL, N_("_Keyboard Shortcuts"),
+      NULL,
+      NULL,
+      G_CALLBACK (help_overlay_cb) },
     { "InstallThemes", NULL, N_("Install card themes…"), NULL,
       N_("Install new card themes from the distribution packages repositories"),
       G_CALLBACK (install_themes_cb) },
@@ -2032,10 +2043,8 @@ aisleriot_window_init (AisleriotWindow *window)
   priv->main_menu = gtk_ui_manager_get_widget (priv->ui_manager, MAIN_MENU_UI_PATH);
   priv->toolbar = gtk_ui_manager_get_widget (priv->ui_manager, TOOLBAR_UI_PATH);
 
-#if GTK_CHECK_VERSION (3, 0, 3)
   gtk_style_context_add_class (gtk_widget_get_style_context (priv->toolbar),
                                GTK_STYLE_CLASS_PRIMARY_TOOLBAR);
-#endif
 
   /* Defer building the card themes menu until its parent's menu is opened */
   action = gtk_action_group_get_action (priv->action_group, "ViewMenu");
